package net.rping.my.web.app;

import java.io.IOException;
import java.lang.reflect.InvocationTargetException;

import android.os.Bundle;
import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Intent;
import android.content.res.AssetManager;
import android.util.Log;
import android.view.KeyEvent;
import android.view.Menu;
import android.view.MenuItem;
import android.webkit.WebSettings;
import android.webkit.WebSettings.PluginState;
import android.webkit.WebView;
import android.webkit.WebViewClient;

public class MainActivity extends Activity {

	private static final String assetRootPath = "file:///android_asset/";
	private static final String localHelloFile	= "hello.html";
	private static final String localAboutFile = "about.html";
	private static final String localWebPath	= "www";
	private static final String indexFileName = "index.htm";
	private static final String LOGTAG = "MYAPP";
	
	private WebView webView;
	
    @SuppressLint("SetJavaScriptEnabled")
	@Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        
        // Create WebView reference to UI elements
        webView = (WebView)findViewById(R.id.webview_component);
        webView.clearCache(true);
        webView.setWebViewClient(new WebViewClient() 
        {
            @Override
            public boolean shouldOverrideUrlLoading(WebView view, String url) 
            {
            	return false;
            	/*
            	if (Uri.parse(url).getHost().equals("www.example.com")) {
                	// This is my web site, so do not override; let my WebView load the page
                    return false;
                }
                // Otherwise, the link is not for a page on my site, so launch another Activity that handles URLs
                Intent intent = new Intent(Intent.ACTION_VIEW, Uri.parse(url));
                startActivity(intent);
                return true;
                */
            }
        });
        
        WebSettings webSettings = webView.getSettings();
        webSettings.setJavaScriptEnabled(true);
        webSettings.setLightTouchEnabled(true);
        webSettings.setDatabaseEnabled(true);
        
        webSettings.setPluginsEnabled(true);
        webSettings.setPluginState(PluginState.ON);
        
        webView.setVerticalScrollBarEnabled(false);
        webView.setHorizontalScrollBarEnabled(false);
        
        loadHome();
    }
    
    public void loadHome()
    {
        AssetManager am = getAssets();
        try {
    		String homepageUrl = PrefHomepage.getHomepageUrl(getApplicationContext());
    		Log.d(LOGTAG, "homepage:" + homepageUrl);
    		
    		if (homepageUrl.length() > 7)
    		{
    			Log.d(LOGTAG, "load from homepage=" + homepageUrl);
    			webView.loadUrl(homepageUrl);
    			return;
    		}

        	Log.d(LOGTAG, "start to find html files");
        	String[] fileArray = am.list(localWebPath);
        	int webViewLoaded = 0;
        	Log.d(LOGTAG, fileArray.length + " files found");
        	for(int i = 0; i < fileArray.length; i++)
        	{
        		Log.d(LOGTAG, i + " " + fileArray[i]);
        		if (fileArray[i].contains(indexFileName))
        		{
        			Log.d(LOGTAG, fileArray[i] + " contains " + indexFileName);
					Log.d(LOGTAG, "loading " + assetRootPath + localWebPath + "/" + fileArray[i]);
        			webView.loadUrl(assetRootPath + localWebPath + "/" + fileArray[i]);
        			webViewLoaded = 1;
        			break;
        		}
        	}
        	if (webViewLoaded == 0) 
        	{
        		for (int i = 0; i < fileArray.length; i++)
        		{
        			Log.d(LOGTAG, i + "/ subdir");
        			String[] subFileArray = am.list(localWebPath + "/" + fileArray[i]);
        			for (int j = 0; j < subFileArray.length; j++)
        			{
        				Log.d(LOGTAG, i + ":" + j + " " + localWebPath + "/" + fileArray[i] + "/" + subFileArray[j]);
        				if (subFileArray[j].contains(indexFileName))
        				{
        					Log.d(LOGTAG, localWebPath + "/" + fileArray[i] + "/" + subFileArray[j] + 
        							" contains " + indexFileName);
        					Log.d(LOGTAG, "loading " + assetRootPath + localWebPath + "/" + fileArray[i] + "/" + subFileArray[j]);
        					webView.loadUrl(assetRootPath + localWebPath + "/" + fileArray[i] + "/" + subFileArray[j]);
        					webViewLoaded = 1;
        					break;
        				}
        			}
        			if (webViewLoaded == 1) break;
        		}
        	}
    		if (webViewLoaded == 0)
    		{
    			Log.d(LOGTAG, "loading " + localHelloFile);
    			webView.loadUrl(assetRootPath + localHelloFile);
    		}
        }
        catch (IOException e)
        {
        	Log.d(LOGTAG, e.getMessage());
        	Log.d(LOGTAG, "loading " + localHelloFile);
        	webView.loadUrl(assetRootPath + localHelloFile);
        }
    }

    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) 
    {
        if(event.getAction() == KeyEvent.ACTION_DOWN)
        {
            switch(keyCode)
            {
            	case KeyEvent.KEYCODE_BACK:
            		if(webView.canGoBack() == true)
            		{
            			webView.goBack();
            		} 
            		else	 
            		{	
            			finish();
            		}
            		return true;
            	case KeyEvent.KEYCODE_HOME:
            		loadHome();
            		return true;
            }

        }
        return super.onKeyDown(keyCode, event);
    }
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.activity_main, menu);
        return true;
    }
    
    public boolean onOptionsItemSelected(MenuItem item) 
    {
        //respond to menu item selection
    	switch (item.getItemId()) 
    	{
    		case R.id.go_home:
    			loadHome();
    			return true;
    		case R.id.about_settings:
    			webView.loadUrl(assetRootPath + localAboutFile);
    			return true;
    		case R.id.menu_settings:
    			startActivity(new Intent(this, PrefActivity.class));
    			return true;
    		default:
    			return super.onOptionsItemSelected(item);
    	}
    }
    
    @Override
    public void onPause() 
    {
        super.onPause();

        try {
            Class.forName("android.webkit.WebView")
                    .getMethod("onPause", (Class[]) null)
                              .invoke(webView, (Object[]) null);

        } catch(ClassNotFoundException cnfe) {
            /* ... */
         } catch(NoSuchMethodException nsme) {
            /* ... */
        } catch(InvocationTargetException ite) {
            /* ... */
        } catch (IllegalAccessException iae) {
            /* ... */
        }
    }
}
